package main

import (
	"fmt"
	"log"
	"os"
	"path/filepath"
	"strings"
)

func main() {
	var err error

	var config Config
	config.load()
	fmt.Printf("%+v\n", config)

	//get working directory
	wd, err := os.Getwd()
	if err != nil {
		log.Fatal("couldn't find working directory", err)
	}

	dir := config.Root + "/chsck"
	randomImg, filename, _ := getRandomFile(dir)
	filenameNoExt := strings.TrimSuffix(filename, filepath.Ext(filename))
	//check to see if rendered copy already exists
	fileExists, err := fileExists(filenameNoExt)
	if err != nil {
		log.Fatal("failure checking if file exists!", err)
	}
	curr := wd + "/images/" + filenameNoExt
	log.Println("curr: ", curr)
	if !fileExists {
		img := loadImage(randomImg)
		dst := processImage(img, config)
		saveImage(curr, dst)
	} else {
		log.Println("file exists! skipping image processing")
	}

	err = hyprpaperPreload(curr)
	if err != nil {
		log.Fatal("preload failed!", err)
	}
	err = hyprpaperWallpaper(curr)
	if err != nil {
		log.Fatal("set wallpaper failed!", err)
	}
	err = hyprpaperUnloadAll()
	if err != nil {
		log.Fatal("unload all failed!", err)
	}
}
